@@ -10,14 +10,28 @@ import pygame
 
 
 def draw(surface):
-    x, y, radius = (250, 250, 200)
+    # Draw three 50% transparent circles: red, green, and blue on a white background
     ctx = cairo.Context(surface)
-    ctx.set_line_width(15)
-    ctx.arc(x, y, radius, 0, 2.0 * math.pi)
-    ctx.set_source_rgb(0.8, 0.8, 0.8)
-    ctx.fill_preserve()
+
     ctx.set_source_rgb(1, 1, 1)
-    ctx.stroke()
+    ctx.paint()
+
+    width, height = 500, 500
+    center_x, center_y = width / 2, height / 2
+    radius = 120
+    offset = 80
+
+    ctx.set_source_rgba(1, 0, 0, 0.5)
+    ctx.arc(center_x - offset, center_y - offset, radius, 0, 2.0 * math.pi)
+    ctx.fill()
+
+    ctx.set_source_rgba(0, 1, 0, 0.5)
+    ctx.arc(center_x + offset, center_y - offset, radius, 0, 2.0 * math.pi)
+    ctx.fill()
+
+    ctx.set_source_rgba(0, 0, 1, 0.5)
+    ctx.arc(center_x, center_y + offset, radius, 0, 2.0 * math.pi)
+    ctx.fill()
 
 
 def input(events):
@@ -40,7 +54,7 @@ def main():
 
     # Create PyGame surface from Cairo Surface
     buf = surface.get_data()
-    image = pygame.image.frombuffer(buf, (width, height), "ARGB")
+    image = pygame.image.frombuffer(buf, (width, height), "BGRA")
     # Tranfer to Screen
     screen.blit(image, (0, 0))
     pygame.display.flip()
